Order class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Order({String id = '', String deviceInfo = '', List<String> tags = const [], String businessId = '', double totalAmountOutstanding = 0.0, double totalAmountPaid = 0.0, double totalPrice = 0.0, double totalCost = 0.0, double currentTotalPrice = 0.0, double subtotalPrice = 0.0, double lineItemTotalPrice = 0.0, double totalLineItemsSold = 0, int totalUniqueLineItems = 0, double totalTip = 0.0, double totalWithdrawal = 0.0, double totalTax = 0.0, double totalDiscount = 0.0, double totalShipping = 0.0, double totalRefunded = 0.0, CapturedChannel capturedChannel = CapturedChannel.undefined, FinancialStatus financialStatus = FinancialStatus.undefined, OrderStatus orderStatus = OrderStatus.undefined, String createdBy = '', String trackingValue = '', int orderNumber = 0, List<TaxInfo> taxes = const [], List<OrderDiscount> discounts = const [], List<OrderLineItem> orderLineItems = const [], List<OrderRefund> refunds = const [], DateTime? dateCreated, DateTime? dateUpdated, String updatedBy = '', List<OrderTransaction> transactions = const [], FulfillmentStatus fulfillmentStatus = FulfillmentStatus.undefined, OrderSource orderSource = OrderSource.undefined, FulfillmentMethod fulfillmentMethod = FulfillmentMethod.undefined, String orderVersion = '', List<OrderHistoryLog> orderHistory = const [], String customerReference = '', String notes = ''})
const
Order.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String
final
capturedChannel CapturedChannel
final
createdBy String
final
currentTotalPrice double
final
customerReference String
final
dateCreated DateTime?
final
dateUpdated DateTime?
final
deviceInfo String
final
discounts List<OrderDiscount>
final
financialStatus FinancialStatus
final
fulfillmentMethod FulfillmentMethod
final
fulfillmentStatus FulfillmentStatus
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lineItemTotalPrice double
final
notes String
final
orderHistory List<OrderHistoryLog>
final
orderLineItems List<OrderLineItem>
final
orderNumber int
final
orderSource OrderSource
final
orderStatus OrderStatus
final
orderVersion String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
refunds List<OrderRefund>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subtotalPrice double
final
tags List<String>
final
taxes List<TaxInfo>
final
totalAmountOutstanding double
final
totalAmountPaid double
final
totalCost double
final
totalDiscount double
final
totalLineItemsSold double
final
totalPrice double
final
totalRefunded double
final
totalShipping double
final
totalTax double
final
totalTip double
final
totalUniqueLineItems int
final
totalWithdrawal double
final
trackingValue String
final
transactions List<OrderTransaction>
final
updatedBy String
final

Methods

copyWith({String? id, String? trackingValue, int? orderNumber, String? deviceInfo, List<String>? tags, String? businessId, double? totalAmountOutstanding, double? totalAmountPaid, double? totalPrice, double? totalCost, double? currentTotalPrice, double? subtotalPrice, double? lineItemTotalPrice, double? totalLineItemsSold, int? totalUniqueLineItems, double? totalTip, double? totalWithdrawal, double? totalTax, double? totalDiscount, double? totalShipping, double? totalRefunded, List<TaxInfo>? taxes, List<OrderDiscount>? discounts, CapturedChannel? capturedChannel, List<OrderLineItem>? orderLineItems, List<OrderRefund>? refunds, FinancialStatus? financialStatus, OrderStatus? orderStatus, DateTime? dateCreated, DateTime? dateUpdated, String? createdBy, String? updatedBy, List<OrderTransaction>? transactions, FulfillmentStatus? fulfillmentStatus, OrderSource? orderSource, FulfillmentMethod? fulfillmentMethod, String? orderVersion, List<OrderHistoryLog>? orderHistory, String? customerReference, String? notes}) Order
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

capturedChannelToJson(CapturedChannel capturedChannel) int
financialStatusToJson(FinancialStatus financialStatus) int
orderStatusToJson(OrderStatus orderStatus) int