OrderDiscount class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OrderDiscount({String id = '', DiscountTarget discountTarget = DiscountTarget.undefined, DiscountValueType type = DiscountValueType.undefined, double value = 0.0})
const
OrderDiscount.cart(double ammount, DiscountValueType type)
factory
OrderDiscount.fromJson(Map<String, dynamic> json)
factory

Properties

discountTarget DiscountTarget
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type DiscountValueType
final
value double
final

Methods

copyWith({String? id, double? value, DiscountValueType? type, DiscountTarget? discountTarget}) OrderDiscount
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited