OrderLineItem class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OrderLineItem({String id = '', String orderId = '', String displayName = '', double unitPrice = 0.0, String businessId = '', String productId = '', double quantity = 0, double subtotalPrice = 0.0, double totalPrice = 0.0, double unitCost = 0.0, bool taxable = false, bool isCombo = false, bool isStockTrackable = false, List<ComboInfo> comboItems = const [], List<OrderDiscount> discounts = const [], String imageUrl = '', String sku = '', TaxInfo taxInfo = const TaxInfo(), String variantId = ''})
const
OrderLineItem.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String
final
comboItems List<ComboInfo>
final
discounts List<OrderDiscount>
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
imageUrl String
final
isCombo bool
final
isStockTrackable bool
final
orderId String
final
productId String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
quantity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subtotalPrice double
final
taxable bool
final
taxInfo TaxInfo
final
totalPrice double
final
unitCost double
final
unitPrice double
final
variantId String
final

Methods

copyWith({String? id, String? orderId, String? displayName, double? unitPrice, double? unitCost, double? subtotalPrice, double? totalPrice, double? quantity, bool? taxable, TaxInfo? taxInfo, String? sku, String? variantId, String? imageUrl, String? businessId, String? productId, List<OrderDiscount>? discounts, bool? isCombo, bool? isStockTrackable, List<ComboInfo>? comboItems}) OrderLineItem
fromQuickSale({String? orderId, String? businessId, String? description, double? amount}) OrderLineItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited