PaymentGatewayAction enum

Inheritance
Available extensions

Values

processPurchase → const PaymentGatewayAction
processPurchaseWithCash → const PaymentGatewayAction
cashback → const PaymentGatewayAction
withdrawal → const PaymentGatewayAction
refund → const PaymentGatewayAction
reversal → const PaymentGatewayAction
tt3 → const PaymentGatewayAction
voidTransaction → const PaymentGatewayAction
getMerchantId → const PaymentGatewayAction
getTerminalId → const PaymentGatewayAction
printReceipt → const PaymentGatewayAction
closeBatch → const PaymentGatewayAction
balanceEnquiry → const PaymentGatewayAction
getTransactionInfo → const PaymentGatewayAction
getBatchNumber → const PaymentGatewayAction
getSerialNumber → const PaymentGatewayAction
getLocation → const PaymentGatewayAction
getVersion → const PaymentGatewayAction
getModelNumber → const PaymentGatewayAction
generateQRCode → const PaymentGatewayAction
printBatchReport → const PaymentGatewayAction
printLastBatchReport → const PaymentGatewayAction
getBatchReports → const PaymentGatewayAction
enrollDevice → const PaymentGatewayAction
enrollMerchant → const PaymentGatewayAction
checkDeviceEnrolmentStatus → const PaymentGatewayAction
checkMerchantEnrolmentStatus → const PaymentGatewayAction
unEnrolTerminal → const PaymentGatewayAction
updateDeviceParameters → const PaymentGatewayAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentGatewayAction>
A constant List of the values in this enum, in order of their declaration.