PaymentPrintResult class

Constructors

PaymentPrintResult({required String status, required String statusCode, required String statusDescription})

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
statusCode String
getter/setter pair
statusDescription String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited