PaymentProvider class abstract

Constructors

PaymentProvider({required String id, required String businessId, required String name, required String description, required bool enabled, required PaymentProviderChannel channel, required PaymentProviderType type, required Map<String, Object> settings, List<String> supportedCurrencies = const [], List<String> blockedPaymentMethods = const [], List<String> supportedPaymentMethods = const []})

Properties

blockedPaymentMethods List<String>
getter/setter pair
businessId String
getter/setter pair
channel PaymentProviderChannel
getter/setter pair
description String
getter/setter pair
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, Object>
getter/setter pair
supportedCurrencies List<String>
getter/setter pair
supportedPaymentMethods List<String>
getter/setter pair
type PaymentProviderType
getter/setter pair

Methods

isValid() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited