OrderRefund class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OrderRefund({String transactionId = '', double totalPrice = 0.0, double subtotalPrice = 0.0, double orderLineItemTotalPrice = 0.0, List<OrderRefundLineItem> refundLineItems = const [], String id = ''})
const
OrderRefund.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
orderLineItemTotalPrice double
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
refundLineItems List<OrderRefundLineItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subtotalPrice double
final
totalPrice double
final
transactionId String
final

Methods

copyWith({String? id, String? transactionId, double? totalPrice, double? subtotalPrice, double? orderLineItemTotalPrice, List<OrderRefundLineItem>? refundLineItems}) OrderRefund
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited