OrderTransaction class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OrderTransaction({double amount = 0.0, String deviceId = '', String businessId = '', CapturedChannel capturedChannel = CapturedChannel.undefined, String orderId = '', PaymentType paymentType = const PaymentType(), TransactionStatus transactionStatus = TransactionStatus.undefined, OrderTransactionType transactionType = OrderTransactionType.undefined, String createdBy = '', EffectOnCartTotal effectOnCartTotal = EffectOnCartTotal.none, String additionalData = '', double amountTendered = 0.0, double changeGiven = 0.0, Customer customer = const Customer(), String failureReason = '', String id = '', String receiptData = '', double tipAmount = 0.0, String traceId = '', int transactionNumber = 0, DateTime? dateCreated, DateTime? dateUpdated, String updatedBy = ''})
const
OrderTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

additionalData String
final
amount double
final
amountTendered double
final
businessId String
final
capturedChannel CapturedChannel
final
changeGiven double
final
createdBy String
final
customer Customer
final
dateCreated DateTime?
final
dateUpdated DateTime?
final
deviceId String
final
effectOnCartTotal EffectOnCartTotal
final
failureReason String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
orderId String
final
paymentType PaymentType
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
receiptData String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tipAmount double
final
traceId String
final
transactionNumber int
final
transactionStatus TransactionStatus
final
transactionType OrderTransactionType
final
updatedBy String
final

Methods

copyWith({String? id, int? transactionNumber, String? businessId, String? deviceId, String? traceId, Customer? customer, String? orderId, double? amount, double? changeGiven, double? amountTendered, double? tipAmount, TransactionStatus? transactionStatus, String? failureReason, OrderTransactionType? transactionType, EffectOnCartTotal? effectOnCartTotal, String? additionalData, CapturedChannel? capturedChannel, String? receiptData, PaymentType? paymentType, DateTime? dateCreated, DateTime? dateUpdated, String? createdBy, String? updatedBy}) OrderTransaction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

orderTransactionTypeToJson(OrderTransactionType orderTransactionType) int
transactionStatusToJson(TransactionStatus transactionStatus) int