PosSessionUpdateRequest<TransactionObject, RefundObject> class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, createFactory: false)
Constructors
-
PosSessionUpdateRequest({required String sessionId, String? businessId, PosPaymentEventStatus? eventStatus, List<
String> ? logs, TransactionObject? transaction, RefundObject? refund})
Properties
- businessId → String?
-
final
- eventStatus → PosPaymentEventStatus?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logs
→ List<
String> ? -
final
- refund → RefundObject?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- transaction → TransactionObject?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited