utils/device_helpers library

Functions

getSoftPosRegisteredDevices({required BusinessService businessService, required LoggerService logger, required String businessId}) Future<int>
getSoftPosRegisteredDevicesByMerchantId({required BusinessService businessService, required LoggerService logger, required String merchantId}) Future<int>
Gets the current registered SoftPOS device count for a business identified by its merchantId (masterMerchantId). The backend resolves the businessId.
isNfcAvailable() Future<bool>
isTablet() bool
updateSoftPosRegisteredDevices({required BusinessService businessService, required LoggerService logger, required String businessId, required bool isAddition, required int currentCount}) Future<int>
updateSoftPosRegisteredDevicesByMerchantId({required BusinessService businessService, required LoggerService logger, required String merchantId, required bool isAddition, required int currentCount}) Future<int>
Updates the registered SoftPOS device count for a business identified by its merchantId (masterMerchantId). The backend resolves the businessId.