PaymentsFormFactor class

Stateless helper that derives layout decisions from MediaQuery.

All methods are static so they can be called directly in build without requiring a provider or singleton.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detect(BuildContext context) PaymentsDisplaySize
Classifies the device into a PaymentsDisplaySize bucket.
useSplitLayout(BuildContext context) bool
Returns true when the split list/detail layout should be used.