hideConfirmButton property
When true, the internal confirm button is hidden. Use this on tablet where an external footer button handles confirm.
Implementation
final bool hideConfirmButton;
When true, the internal confirm button is hidden. Use this on tablet where an external footer button handles confirm.
final bool hideConfirmButton;