isRefund property
Whether this leg represents a refund event. When true, the amount is displayed as negative with error color and a "Refund" badge is shown.
Implementation
final bool isRefund;
Whether this leg represents a refund event. When true, the amount is displayed as negative with error color and a "Refund" badge is shown.
final bool isRefund;