ReceiptManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildAndPrintReceipts(
{required String merchantName, required String merchantId, required String terminalId, required ReceiptType receiptType, PaymentResult? paymentResult, SettlementResult? settlementResult, BalanceInquiryResult? balanceInquiryResult, required PaymentGateway< PaymentProvider> paymentGateway}) → Future<void> -
doBold(
) → String -
feedLine(
{int nr = 1}) → String -
formatLabelValue(
{String label = '', String value = ''}) → String -
formatTextContent(
{String text = '', String alignment = 'c'}) → String -
newLine(
) → String -
notBold(
) → String