OrderHistoryLog class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- changeDate → String
-
final
- changedBy → String
-
final
- changeId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newState → String
-
final
- notes → String
-
final
- orderId → String
-
final
- previousState → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- reason → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? orderId, String? changeId, String? previousState, String? newState, String? changedBy, String? changeDate, String? reason, String? notes}) → OrderHistoryLog -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited