PaymentHostConfig class
Host-app-provided configuration for the payments package.
The host app creates and registers this via LittleFishCore during
payment injection so that the payments package never needs to reach
into enterprise config (LaunchDarkly) directly.
Constructors
- PaymentHostConfig({required bool appControlledReceiptPrinting})
-
const
Properties
- appControlledReceiptPrinting → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited