ProviderTheme class
Constructors
- ProviderTheme({Color primaryColor = Colors.grey, Color secondaryColor = Colors.white, Color successColor = Colors.green, Color failureColor = Colors.red})
-
const
Properties
- failureColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor → Color
-
final
- successColor → Color
-
final
Methods
-
copyWith(
{Color? primaryColor, Color? secondaryColor, Color? successColor, Color? failureColor}) → ProviderTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited