PosSessionRequest<TransactionObject> class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, createFactory: false)
Constructors
-
PosSessionRequest({String? providerName, required PaymentEventType eventType, required String businessId, required String merchantId, required String description, required double amount, required String currency, required TransactionObject? transaction, bool requiresProvider = true, Map<String, dynamic>? additionalData, String orderId = ''})
-
Properties
-
additionalData
→ Map<String, dynamic>?
-
Holds additional data that may be required by the payment provider.
final
-
amount
→ double
-
The amount of the payment to be processed
final
-
businessId
→ String
-
(Optional) The Business identifier for the payment session
If MerchantId is not provided, we use this to get the MerchantId
final
-
currency
→ String
-
The currency code for the payment
final
-
description
→ String
-
The description of the payment
final
-
eventType
→ PaymentEventType
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
merchantId
→ String
-
(Optional) The merchant identifier for the payment session
final
-
orderId
→ String
-
The order identifier associated with the payment session
final
-
providerName
→ String?
-
Provider name for the payment session
final
-
requiresProvider
→ bool
-
Indicates if this session requires an external payment provider.
Defaults to true.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
transaction
→ TransactionObject?
-
Assumed to be CheckoutTransaction object, representing the full transaction details
final