businessId property
(Optional) The Business identifier for the payment session If MerchantId is not provided, we use this to get the MerchantId
Implementation
final String businessId;
(Optional) The Business identifier for the payment session If MerchantId is not provided, we use this to get the MerchantId
final String businessId;